<?php
// ------------------------------------------------ 
// ---------- Options Framework Theme -------------
// ------------------------------------------------
 include( get_template_directory() . '/inc/Acid/acid.php' ); 

// ---------------------------------------------- 
// --------------- Load Custom Widgets ----------
// ----------------------------------------------
 include( get_template_directory() . '/inc/widgets.php');


// ----------------------------------------------
// --------------- Load Custom ------------------
// ---------------------------------------------- 
 include( get_template_directory() . '/inc/custom/comments.php');
  
// ----------------------------------------------
// ------ Content width -------------------------
// ----------------------------------------------
if ( ! isset( $content_width ) ) $content_width = 910;

// ----------------------------------------------
// ------ Theme set up --------------------------
// ----------------------------------------------
add_action( 'after_setup_theme', 'quemag_wp_theme_setup' );
if ( !function_exists('quemag_wp_theme_setup') ) {

    function quemag_wp_theme_setup() {
    
        // Register navigation menu
        register_nav_menus(
            array(
                'quemag-wp-primary-menu' => esc_html__( 'Header Navigation', 'quemag-wp' ),
                'quemag-wp-secondary-menu' => esc_html__( 'Categories Navigation', 'quemag-wp' ),
            )
        );
        
        // Localization support
        load_theme_textdomain( 'quemag-wp', get_template_directory() . '/languages' );
        
        // Feed Links
        add_theme_support( 'automatic-feed-links' );
        
        // Title Tag
        add_theme_support( 'title-tag' );

        // Post thumbnails
        add_theme_support( 'post-thumbnails' );
        add_image_size( 'quemag-wp-thumbnail-comments', 350, '', true ); // Comments crop images
        add_image_size( 'quemag-wp-thumbnail-module-grid', 242, 180, true ); // Blog thumbnails home module
        add_image_size( 'quemag-wp-thumbnail-widget-big', 250, 180, true ); // Sidebar Widget thumbnails big
        add_image_size( 'quemag-wp-thumbnail-widget-small', 75, 75, true ); // Sidebar Widget thumbnails small
        add_image_size( 'quemag-wp-thumbnail-single-image', 910, '', true ); // Article Big thumbnail
        add_image_size( 'quemag-wp-thumbnail-blog-featured', 670, 490, true ); // Blog thumbnails home featured posts
        add_image_size( 'quemag-wp-thumbnail-blog-featured-small', 320, 228, true ); // Blog small thumbnails home featured posts
        add_image_size( 'quemag-wp-thumbnail-blog-list', 300, 225, true ); // Thumbnails home blog

    }
}

// ----------------------------------------------
// ------------ JavaScrips Files ----------------
// ----------------------------------------------
if( !function_exists( 'quemag_wp_enqueue_scripts' ) ) {
    function quemag_wp_enqueue_scripts() {

        // Register css files
        wp_enqueue_style( 'quemag-wp-style', get_stylesheet_uri(), '', '1.1');
        wp_enqueue_style( 'quemag-wp-default', get_template_directory_uri() . '/css/colors/default.css', array( 'quemag-wp-style' ), '1.1' );
        wp_enqueue_style( 'quemag-wp-responsive', get_template_directory_uri() . '/css/responsive.css', array( 'quemag-wp-style' ), '1.1' );
        wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/css/fontawesome-free-5.13.1-web/css/all.min.css', array(), '5.13.1' );

        // Register scripts
        wp_enqueue_script( 'quemag-wp-customjs', get_template_directory_uri() . '/js/custom.js', array( 'jquery' ), '1.1', true );
        wp_enqueue_script( 'jquery-sticky-kit',  get_template_directory_uri() . '/js/jquery.sticky-kit.js', array( 'jquery' ), '1.1.2', true );
        wp_enqueue_script( 'masonry' );
        
        // Load Comments & .js files.
        if( is_single() ) {
            wp_enqueue_script( 'comment-reply' );
         }

// ----------------------------------------------
// Register Fonts: https://gist.github.com/kailoon/e2dc2a04a8bd5034682c
// ----------------------------------------------
        function quemag_wp_fonts_url() {
            $quemag_wp_font_url_google = '';
            
            /*
            Translators: If there are characters in your language that are not supported
            by chosen font(s), translate this to 'off'. Do not translate into your own language.
             */
            if ( 'off' !== _x( 'on', 'Google font: on or off', 'quemag-wp' ) ) {
                $quemag_wp_font_url_google = add_query_arg( 'family', urlencode( 'Ruda:400,700,900|Oswald:500' ), "//fonts.googleapis.com/css" );
            }
            return $quemag_wp_font_url_google;
        }
        /* -- Enqueue styles -- */
        wp_enqueue_style( 'quemag_wp_fonts', quemag_wp_fonts_url(), array(), '1.0.0' );
  

    }
    add_action('wp_enqueue_scripts', 'quemag_wp_enqueue_scripts');
}


// ----------------------------------------------
// ---------- excerpt length adjust -------------
// ----------------------------------------------
function quemag_wp_excerpt($str, $length, $minword = 3) {
    $sub = '';
    $len = 0;
    foreach (explode(' ', $str) as $word) {
        $part = (($sub != '') ? ' ' : '') . $word;
        $sub .= $part;
        $len += strlen($part);
        if (strlen($word) > $minword && strlen($sub) >= $length) { break; }
    }
    return $sub . (($len < strlen($str)) ? ' ..' : '');
}


// ------------------------------------------------ 
// --- Characters limit for title -----------------
// ------------------------------------------------ 
function quemag_wp_the_title($length, $replacer = ' ..') {
    $string = get_the_title();
    if( mb_strlen( $string ) > $length ) {
        $string = mb_substr( $string, 0, $length-3 );
        echo esc_attr($string) . $replacer;
    } else echo esc_attr($string);
}


// ----------------------------------------------
// ------ Different letter for search box  ------
// ----------------------------------------------
function my_query_vars_quemag( $public_query_vars ) {
    if ( isset( $_GET['q'] ) && ! empty( $_GET['q'] ) ) {
        $_GET['s'] = $_GET['q'];
    }
    return $public_query_vars;
}
add_filter( 'query_vars', 'my_query_vars_quemag' );


// ------------------------------------------------ 
// ------------ Nr of Topics for Tags -------------
// ------------------------------------------------  
function tag_cloud_count_anthemes($content, $tags, $args)
{ 
  $count=0;
  $output=preg_replace_callback('(</a\s*>)', 
  function($match) use ($tags, &$count) {
      return "<span class=\"tagcount\"> (".$tags[$count++]->count.")</span></a>";  
  }
  , $content);
  
  return $output;
}
add_filter('wp_generate_tag_cloud','tag_cloud_count_anthemes', 10, 3); 


// ------------------------------------------------ 
// --- Pagination class/style for entry articles --
// ------------------------------------------------ 
function custom_nextpage_links_quemag_wp($defaults) {
$args = array(
'before' => '<div class="my-paginated-posts"><p>' . '<span>',
'after' => '</span></p></div>',
);
$r = wp_parse_args($args, $defaults);
return $r;
}
add_filter('wp_link_pages_args','custom_nextpage_links_quemag_wp');


// ------------------------------------------------ 
// --- One Click Demo Import (Plugin) -------------
// ------------------------------------------------ 
function quemag_wp_plugin_intro_text( $quemag_wp_default_text ) {
    $quemag_wp_default_text =  /* https://wordpress.org/plugins/one-click-demo-import/faq/ the inline style is added for the demo import plugin, that is displayed via Dashboard > Appearance. */ '<div class="ocdi__intro-text">'. esc_html__( 'Please click "Import Demo Data" button only once and wait, it can take a couple of minutes.', 'quemag-wp' ) .'</div><br />';?><br /><br /> In the meantime, you check the <a href="https://anthemes.com/docs/quemag/" target="_blank">help file</a> or <a href="https://themeforest.net/item/quemag-creative-wordpress-theme-for-bloggers/28383576/support" target="_blank">get support</a>.<?php
    return $quemag_wp_default_text;
}
add_filter( 'pt-ocdi/plugin_intro_text', 'quemag_wp_plugin_intro_text' );

function ocdi_import_files() {
    return array(
        array(
            'import_file_name'             => esc_html__( 'Quemag', 'quemag-wp' ),
            'categories'                   => array( 'Magazine' ),
            'local_import_file'            => trailingslashit( get_template_directory() ) . '/inc/demo/demo1.xml',
            'local_import_widget_file'     => trailingslashit( get_template_directory() ) . '/inc/demo/demo1.wie',
            'local_import_customizer_file' => trailingslashit( get_template_directory() ) . '/inc/demo/demo1.dat',
            'import_preview_image_url'     => esc_url(get_template_directory_uri() ) . '/inc/demo/quemag.jpg',
            'preview_url'                  => 'https://anthemes.com/themes/quemag/',
        ),
        array(
            'import_file_name'             => esc_html__( 'Qnews', 'quemag-wp' ),
            'categories'                   => array( 'News' ),
            'local_import_file'            => trailingslashit( get_template_directory() ) . '/inc/demo/demo2.xml',
            'local_import_widget_file'     => trailingslashit( get_template_directory() ) . '/inc/demo/demo2.wie',
            'local_import_customizer_file' => trailingslashit( get_template_directory() ) . '/inc/demo/demo2.dat',
            'import_preview_image_url'     => esc_url(get_template_directory_uri() ) . '/inc/demo/qnews.jpg',
            'preview_url'                  => 'https://anthemes.com/themes/quenews/',
        ),
        array(
            'import_file_name'             => esc_html__( 'Qrecipes', 'quemag-wp' ),
            'categories'                   => array( 'Food' ),
            'local_import_file'            => trailingslashit( get_template_directory() ) . '/inc/demo/demo3.xml',
            'local_import_widget_file'     => trailingslashit( get_template_directory() ) . '/inc/demo/demo3.wie',
            'local_import_customizer_file' => trailingslashit( get_template_directory() ) . '/inc/demo/demo3.dat',
            'import_preview_image_url'     => esc_url(get_template_directory_uri() ) . '/inc/demo/qrecipes.jpg',
            'preview_url'                  => 'https://anthemes.com/themes/querecipes/',
        ),

    );
}

add_filter( 'pt-ocdi/import_files', 'ocdi_import_files' );
add_filter( 'pt-ocdi/disable_pt_branding', '__return_true' );

function ocdi_after_import_setup() {
    // Assign menus to their locations.
    $main_menu = get_term_by( 'name', 'Header Navigation', 'nav_menu' );
    $main_menu2 = get_term_by( 'name', 'Categories Navigation', 'nav_menu' );

    set_theme_mod( 'nav_menu_locations', array(
            'quemag-wp-primary-menu' => $main_menu->term_id, 
            'quemag-wp-secondary-menu' => $main_menu2->term_id,
        )
    );

    // Assign front page and posts page (blog page).
    $front_page_id = get_page_by_title( 'Home' );

    update_option( 'show_on_front', 'page' );
    update_option( 'page_on_front', $front_page_id->ID );

}
add_action( 'pt-ocdi/after_import', 'ocdi_after_import_setup' );


// ------------------------------------------------ 
// ---------- TGM_Plugin_Activation ---------------
// ------------------------------------------------ 
 include( get_template_directory() . '/inc/custom/class-tgm-plugin-activation.php');
 add_action( 'tgmpa_register', 'quemag_wp_register_required_plugins' );

function quemag_wp_register_required_plugins() {

    $plugins = array(
        array(
            'name'                  => esc_html__( 'Quemag Theme Core', 'quemag-wp' ), // The plugin name
            'slug'                  => 'quemag-wp-options', // The plugin slug (typically the folder name)
            'source'                => get_template_directory() . '/inc/plugins/quemag-wp-options.zip', // The plugin source
            'required'              => true, // If false, the plugin is only 'recommended' instead of required
            'version'               => '1.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher, otherwise a notice is presented
            'force_activation'      => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch
            'force_deactivation'    => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins
            'external_url'          => '', // If set, overrides default API URL and points to an external URL
        ),

        array(
            'name'                  => esc_html__( 'Meta Box', 'quemag-wp' ),
            'slug'                  => 'meta-box',
            'required'              => false,
            'version'               => '',
        ),

        array(
            'name'                  => esc_html__( 'WP-PageNavi', 'quemag-wp' ),
            'slug'                  => 'wp-pagenavi',
            'required'              => false,
            'version'               => '',
        ),

        array(
            'name'                  => esc_html__( 'DCO Comment Attachment', 'quemag-wp' ),
            'slug'                  => 'dco-comment-attachment',
            'required'              => false,
            'version'               => '',
        ),

        array(
            'name'                  => esc_html__( 'Contact Form 7', 'quemag-wp' ),
            'slug'                  => 'contact-form-7',
            'required'              => false,
            'version'               => '',
        ),

        array(
            'name'                  => esc_html__( 'MailChimp for WordPress', 'quemag-wp' ),
            'slug'                  => 'mailchimp-for-wp',
            'required'              => false,
            'version'               => '',
        ), 

        array(
            'name'                  => esc_html__( 'WP Recipe Maker', 'quemag-wp' ),
            'slug'                  => 'wp-recipe-maker',
            'required'              => false,
            'version'               => '',
        ), 

        array(
            'name'                  => esc_html__( 'One Click Demo Import', 'quemag-wp' ),
            'slug'                  => 'one-click-demo-import',
            'required'              => false,
            'version'               => '',
        ),  

    );

    $config = array(
        'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
        'default_path' => '',                      // Default absolute path to bundled plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'parent_slug'  => 'themes.php',            // Parent menu slug.
        'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.

    );

    tgmpa( $plugins, $config );

}

?>